==> gradle-7.5-rc-2-src.zip: gradle-7.5-rc-2/subprojects/diagnostics/src/main/java/org/gradle/api/reporting/components/internal/DiagnosticsServices.java <==
/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.reporting.components.internal;

import org.gradle.api.plugins.internal.HelpBuiltInCommand;
import org.gradle.internal.service.ServiceRegistration;
import org.gradle.internal.service.scopes.AbstractPluginServiceRegistry;
import org.gradle.model.internal.manage.schema.ModelSchemaStore;

import java.util.List;

public class DiagnosticsServices extends AbstractPluginServiceRegistry {
    @Override
    @SuppressWarnings("rawtypes")
    public void registerGlobalServices(ServiceRegistration registration) {
        registration.add(HelpBuiltInCommand.class);
        registration.addProvider(new Object() {
            TypeAwareBinaryRenderer createBinaryRenderer(List<AbstractBinaryRenderer> renderers, ModelSchemaStore schemaStore) {
                TypeAwareBinaryRenderer renderer = new TypeAwareBinaryRenderer();
                renderer.register(new BinaryRenderer(schemaStore));
                for (AbstractBinaryRenderer<?> binaryRenderer : renderers) {
                    renderer.register(binaryRenderer);
                }
                return renderer;
            }
        });
    }
}

==> gradle-8.9-src.zip: gradle-8.9/subprojects/diagnostics/src/main/java/org/gradle/api/reporting/components/internal/DiagnosticsServices.java <==
/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.reporting.components.internal;

import org.gradle.api.plugins.internal.HelpBuiltInCommand;
import org.gradle.internal.service.Provides;
import org.gradle.internal.service.ServiceRegistration;
import org.gradle.internal.service.ServiceRegistrationProvider;
import org.gradle.internal.service.scopes.AbstractGradleModuleServices;
import org.gradle.model.internal.manage.schema.ModelSchemaStore;

import java.util.List;

public class DiagnosticsServices extends AbstractGradleModuleServices {
    @Override
    public void registerGlobalServices(ServiceRegistration registration) {
        registration.add(HelpBuiltInCommand.class);
        registration.addProvider(new ServiceRegistrationProvider() {
            @Provides
            @SuppressWarnings("rawtypes")
            TypeAwareBinaryRenderer createBinaryRenderer(List<AbstractBinaryRenderer> renderers, ModelSchemaStore schemaStore) {
                TypeAwareBinaryRenderer renderer = new TypeAwareBinaryRenderer();
                renderer.register(new BinaryRenderer(schemaStore));
                for (AbstractBinaryRenderer<?> binaryRenderer : renderers) {
                    renderer.register(binaryRenderer);
                }
                return renderer;
            }
        });
    }
}
